package postgres

import (
	"context"
	"database/sql"

	"github.com/google/uuid"
)

// NewBudget creates a budget and adds it to the current user
func (s *Database) NewBudget(context context.Context, name string, userID uuid.UUID) (*Budget, error) {
	tx, err := s.BeginTx(context, &sql.TxOptions{})
	q := s.WithTx(tx)
	budget, err := q.CreateBudget(context, name)
	if err != nil {
		return nil, err
	}

	ub := LinkBudgetToUserParams{UserID: userID, BudgetID: budget.ID}
	_, err = q.LinkBudgetToUser(context, ub)
	if err != nil {
		return nil, err
	}

	return &budget, nil
}
